@@ -1,5 +1,5 @@
 .onLoad <- function(lib, pkg) {
-    pkgs <- c("methods", "stashR")
+    pkgs <- c("stashR")
 
     for(pkg in pkgs) {
         if(!require(pkg, quietly = TRUE, character.only = TRUE))
@@ -10,10 +10,11 @@
 
 .onAttach <- function(lib, pkg) {
     dcf <- read.dcf(file.path(lib, pkg, "DESCRIPTION"))
-    msg <- gettextf("%s (version %s %s)", dcf[, "Title"],
+    msg <- gettextf("%s (%s %s)", dcf[, "Title"],
                     as.character(dcf[, "Version"]), dcf[, "Date"])
-    writeLines(strwrap(msg))
-    writeLines(strwrap("Initialize database using 'initDB'"))
+    message(paste(strwrap(msg), collapse = "\n"))
+    message(paste(strwrap(gettext("Initialize database using 'initDB'")),
+                  collapse = "\n"))
 }
 
 .dbEnv <- new.env()
